<?php
// no direct access
defined('ABSPATH') or die();

if(!class_exists('LSDR_Theme')):

/**
 * Theme Class
 *
 * @class LSDR_Theme
 * @version	1.0.0
 */
class LSDR_Theme extends LSDR_Base
{
    /**
     * Constructor
     */
    public function __construct()
    {
        parent::__construct();
    }

    public function init()
    {
        add_action('after_setup_theme', array($this, 'setup'));
        add_action('after_setup_theme', array($this, 'content_width'), 0);
		
        add_filter('body_class', array($this, 'body_classes'));
        add_action('wp_head', array($this, 'pingback_header'));
    }
	
    public function setup()
    {
        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         */
        add_theme_support('title-tag');

        /*
         * Enable support for Post Thumbnails on posts and pages.
         */
        add_theme_support('post-thumbnails');

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
            'style',
            'script',
			'navigation-widgets',
        ));

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        /**
         * Add support for core custom logo.
         */
        add_theme_support('custom-logo', array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        ));
		
		/**
         * Add support for editors style.
         */
		add_theme_support('editor-styles');
		
		/**
         * Add support for block style.
         */
		add_theme_support('wp-block-styles');
		
		/**
         * Add support for responsive embeds.
         */
		add_theme_support('responsive-embeds');
		
		/**
         * Add support for align wide.
         */
		add_theme_support('align-wide');
    }

    public function content_width()
    {
        $GLOBALS['content_width'] = apply_filters('lsdr_content_width', 640); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
    }

    public function body_classes($classes)
    {
        // Adds a class of hfeed to non-singular pages.
        if(!is_singular()) $classes[] = 'hfeed';

        return $classes;
    }

    /**
     * Add a pingback url auto-discovery header for single posts, pages, or attachments.
     */
    public function pingback_header()
    {
        if(is_singular() and pings_open())
        {
            printf('<link rel="pingback" href="%s">', esc_url(get_bloginfo('pingback_url')));
        }
    }

    public static function logo()
    {
        if((is_front_page() or is_home()) and !is_page()) return '<h1 class="site-logo">'.get_custom_logo().'</h1>';
        else return '<div class="site-logo">'.get_custom_logo().'</div>';
    }
}

endif;